..
 This work is licensed under a Creative Commons Attribution 3.0 Unported
 License.

 http://creativecommons.org/licenses/by/3.0/legalcode

..
 This template should be in ReSTructured text. The filename in the git
 repository should match the launchpad URL, for example a URL of
 https://blueprints.launchpad.net/kolla/+spec/awesome-thing should be named
 awesome-thing.rst . Please do not delete any of the sections in this
 template. If you have nothing to say for a whole section, just write: None
 For help with syntax, see http://sphinx-doc.org/rest.html
 To test out your formatting, see http://www.tele3.cz/jbar/rest/rest.html

===========================
The title of your blueprint
===========================

Include the URL of your launchpad blueprint:

https://blueprints.launchpad.net/kolla/+spec/example

Introduction paragraph -- why are we doing anything?

Problem description
===================

A detailed description of the problem.

Use cases
---------
1. TODO

Proposed change
===============

Here is where you cover the change you propose to make in detail. How do you
propose to solve this problem?

If this is one part of a larger effort make it clear where this piece ends. In
other words, what's the scope of this effort?

Include where in the kolla tree hierarchy this will reside.

Security impact
---------------
How does this feature impact the securtiy of the deployed OpenStack.

Performance Impact
------------------
Does this feature impact the performance of the deployment or the
resultant OpenStack installation.

Alternatives
------------

This is an optional section, where it does apply we'd just like a demonstration
that some thought has been put into why the proposed approach is the best one.

Implementation
==============

Assignee(s)
-----------

Who is leading the writing of the code? Or is this a blueprint where you're
throwing it out there to see who picks it up?

If more than one person is working on the implementation, please designate the
primary author and contact.

Primary assignee:
  <launchpad-id or None>

Can optionally can list additional ids if they intend on doing
substantial implementation work on this blueprint.

Milestones
----------

Target Milestone for completion:
  mitaka-1

Work Items
----------

Work items or tasks -- break the feature up into the things that need to be
done to implement it. Those parts might end up being done by different people,
but we're mostly trying to understand the timeline for implementation.

Testing
=======
How are you proposing to test this feature.

Documentation Impact
====================
What documentation will be done to describe this feature to developers
and operators.

References
==========
Any links to external documentation.
